Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(560)

Unified Diff: components/sync/api/metadata_batch.h

Issue 2222373003: [Sync] Adding storage key concept for ModelTypeServices. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Removing redundant hash value. Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/sync/api/fake_model_type_service.cc ('k') | components/sync/api/metadata_batch.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/sync/api/metadata_batch.h
diff --git a/components/sync/api/metadata_batch.h b/components/sync/api/metadata_batch.h
index 79da85bfebe6cdb4cbf39d4169a42820da44e987..e59fcf8fae36f4a69c98870d52d1118578d99b60 100644
--- a/components/sync/api/metadata_batch.h
+++ b/components/sync/api/metadata_batch.h
@@ -14,7 +14,7 @@
namespace syncer_v2 {
// Map of client tag to EntityMetadata proto.
typedef std::map<std::string, sync_pb::EntityMetadata> EntityMetadataMap;
// Container used to pass sync metadata from services to their processor.
@@ -28,8 +28,8 @@ class SYNC_EXPORT MetadataBatch {
// protos from the map for performance reasons.
EntityMetadataMap&& TakeAllMetadata();
- // Add |metadata| for |client_tag| to the batch.
- void AddMetadata(const std::string& client_tag,
+ // Add |metadata| for |storage_key| to the batch.
+ void AddMetadata(const std::string& storage_key,
const sync_pb::EntityMetadata& metadata);
// Get the DataTypeState for this batch.
« no previous file with comments | « components/sync/api/fake_model_type_service.cc ('k') | components/sync/api/metadata_batch.cc » ('j') | no next file with comments »
@@ -14,7 +14,7 @@
namespace syncer_v2 {
-// Map of client tag to EntityMetadata proto.
+// Map of storage keys to EntityMetadata proto.
typedef std::map<std::string, sync_pb::EntityMetadata> EntityMetadataMap;
// Container used to pass sync metadata from services to their processor.

Powered by Google App Engine
This is Rietveld 408576698